==> momosimplebbs0.1.1.zip: momosimplebbs0.1.1/src/index.php <==
<?php
/**
 * momo simple BBS
 * TOP page
 */
header("Content-Type: text/html; charset=Shift_JIS");
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
header("Cache-Control: no-store, no-cache, must-revalidate");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

require_once("common.php");

$num = $_GET['num'];
if (empty($num) || !is_numeric($num)) {
    $num = 0;
}
$num = (int)$num;


?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=shift_jis">
    <title><?php print $bbsName; ?></title>
    <link rel="stylesheet" href="momosimplebbs.css" type="text/css">
</head>
<body>
<div class="header">
    <h2><?php print $bbsName; ?></h2>
</div>
<hr>
<div class="post">
<form name="sousin" action="postresult.php" method="POST">
<table class="postmessage">
<tr>
    <td class="postmessage">^Cg</td>
    <td class="postmessage"><input type="text" name="title"size="50" style="ime-mode:active"></td>
</tr>
<tr>
    <td class="postmessage">O</td>
    <td class="postmessage"><input type="text" name="name" size="30" style="ime-mode:active"></td>
</tr>
<tr>
    <td class="postmessage">e</td>
    <td class="postmessage"><textarea name="message" rows="5" cols="40" style="ime-mode:active"></textarea></td>
</tr>
<tr>
    <td class="postmessage" colspan="2"><input type="submit" value="M"></td>
</tr>
</table>
</form>
</div>
<?php
    viewLogNumber($num);
?>
<hr>
<div class="message">
<?php
   /* Oǂݍݏ */
    viewLogs($num);
?>
</div>
<hr>
<div class="footer">
    <?php print $bbsName; ?>
<!--
<form name="kanri" action="" method="POST">
  ǗpF<input type="password" name="pass">  
  <input type="submit" value="M">
</form>
-->
</div>
</body>
</html>

==> momosimplebbs-0.1.3.zip: momosimplebbs-0.1.3/src/index.php <==
<?php
/**
 * momo simple BBS
 * TOP page
 */
header("Content-Type: text/html; charset=EUC-JP");
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
header("Cache-Control: no-store, no-cache, must-revalidate");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

require_once("common.php");

$num = $_GET['num'];
if (empty($num) || !is_numeric($num)) {
    $num = 0;
}
$num = (int)$num;


?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
    <meta http-equiv="Content-Type" content="text/html; charset=EUC-JP">
    <title><?php print $bbsName; ?></title>
    <link rel="stylesheet" href="momosimplebbs.css" type="text/css">
</head>
<body>
<div class="header">
    <h2><?php print $bbsName; ?></h2>
</div>
<div class="post">
<form name="sousin" action="postresult.php" method="POST">
<table>
<tr>
    <td><b>̾</b></td>
    <td><input type="text" name="name" size="50" style="ime-mode:active"></td>
</tr>
<tr>
    <td><b>ȥ</b></td>
    <td><input type="text" name="title"size="50" style="ime-mode:active"></td>
</tr>
<tr>
    <td colspan="2"><b></b></td>
</tr>
<tr>
    <td colspan="2"><textarea name="message" rows="5" cols="56" style="ime-mode:active"></textarea></td>
</tr>
<tr>
    <td colspan="2"><input type="submit" value=""></td>
</tr>
</table>
</form>
</div>
<?php
    viewLogNumber($num);
?>
<hr>
<div class="message">
<?php
   /* ɤ߹߽ */
    viewLogs($num);
?>
</div>
<hr>
<div class="footer">
    <?php viewFooter(); ?>
</div>
</body>
</html>
